@@ -35,14 +35,29 @@ class Analyzer(sc.prettyobj):
             label = self.__class__.__name__ # Use the class name if no label is supplied
         self.label = label # e.g. "Record ages"
         self.initialized = False
+        self.finalized = False
         return
 
 
-    def initialize(self, sim):
+    def initialize(self, sim=None):
         '''
         Initialize the analyzer, e.g. convert date strings to integers.
         '''
         self.initialized = True
+        self.finalized = False
+        return
+
+
+    def finalize(self, sim=None):
+        '''
+        Finalize analyzer
+
+        This method is run once as part of `sim.finalize()` enabling the analyzer to perform any
+        final operations after the simulation is complete (e.g. rescaling)
+        '''
+        if self.finalized:
+            raise Exception('Analyzer already finalized')  # Raise an error because finalizing multiple times has a high probability of producing incorrect results e.g. applying rescale factors twice
+        self.finalized = True
         return
 
 
@@ -161,10 +176,10 @@ class snapshot(Analyzer):
             date = self.dates[ind]
             self.snapshots[date] = sc.dcp(sim.people) # Take snapshot!
 
-        # On the final timestep, check that everything matches
-        if sim.t == sim.tvec[-1]:
-            validate_recorded_dates(sim, requested_dates=self.dates, recorded_dates=self.snapshots.keys(), die=self.die)
 
+    def finalize(self, sim):
+        super().finalize()
+        validate_recorded_dates(sim, requested_dates=self.dates, recorded_dates=self.snapshots.keys(), die=self.die)
         return
 
 
@@ -285,10 +300,10 @@ class age_histogram(Analyzer):
                 inds = sim.people.defined(f'date_{state}') # Pull out people for which this state is defined
                 self.hists[date][state] = np.histogram(age[inds], bins=self.edges)[0]*scale # Actually count the people
 
-        # On the final timestep, check that everything matches
-        if sim.t == sim.tvec[-1]:
-            validate_recorded_dates(sim, requested_dates=self.dates, recorded_dates=self.hists.keys(), die=self.die)
 
+    def finalize(self, sim):
+        super().finalize()
+        validate_recorded_dates(sim, requested_dates=self.dates, recorded_dates=self.hists.keys(), die=self.die)
         return
 
 
@@ -1585,7 +1600,7 @@ class TransTree(Analyzer):
         # Construct each frame of the animation
         detailed = self.detailed.to_dict('records') # Convert to the old style
         for ddict in detailed:  # Loop over every person
-            if ddict is None:
+            if np.isnan(ddict['source']):
                 continue # Skip the 'None' node corresponding to seeded infections
 
             frame = {}
