@@ -228,7 +228,7 @@ def title_grid_legend(ax, title, grid, commaticks, setylim, legend_args, show_le
     return
 
 
-def date_formatter(start_day=None, dateformat=None, ax=None, sim=None):
+def date_formatter(start_day=None, dateformat=None, interval=None, start=None, end=None, ax=None, sim=None):
     '''
     Create an automatic date formatter based on a number of days and a start day.
 
@@ -238,16 +238,22 @@ def date_formatter(start_day=None, dateformat=None, ax=None, sim=None):
 
     Args:
         start_day (str/date): the start day, either as a string or date object
-        dateformat (str): the date format
+        dateformat (str): the date format (default '%b-%d')
+        interval (int): if supplied, the interval between ticks (must supply an axis also to take effect)
+        start (str/int): if supplied, the lower limit of the axis
+        end (str/int): if supplied, the upper limit of the axis
         ax (axes): if supplied, automatically set the x-axis formatter for this axis
         sim (Sim): if supplied, get the start day from this
 
     **Examples**::
 
-        cv.date_formatter(sim=sim, ax=ax) # Automatically configure the axis with default options
+        # Automatically configure the axis with default option
+        cv.date_formatter(sim=sim, ax=ax) s
 
-        formatter = cv.date_formatter(start_day='2020-04-04', dateformat='%Y-%m-%d') # Manually configure
-        ax.xaxis.set_major_formatter(formatter)
+        # Manually configure
+        ax = pl.subplot(111)
+        ax.plot(np.arange(60), np.random.random(60))
+        formatter = cv.date_formatter(start_day='2020-04-04', interval=7, start='2020-05-01', end=50, dateformat='%Y-%m-%d', ax=ax)
     '''
 
     # Set the default -- "Mar-01"
@@ -257,16 +263,31 @@ def date_formatter(start_day=None, dateformat=None, ax=None, sim=None):
     # Convert to a date object
     if start_day is None and sim is not None:
         start_day = sim['start_day']
+    if start_day is None:
+        errormsg = 'If not supplying a start day, you must supply a sim object'
+        raise ValueError(errormsg)
     start_day = sc.date(start_day)
 
     @ticker.FuncFormatter
     def mpl_formatter(x, pos):
-        if sc.isnumber(x): # If the axis doesn't have date units
-            return (start_day + dt.timedelta(days=int(x))).strftime(dateformat)
-        else: # If the axis does
-            return x.strftime(dateformat)
+        return (start_day + dt.timedelta(days=int(x))).strftime(dateformat)
 
+    # Set initial tick marks (intervals and limits)
     if ax is not None:
+
+        # Handle limits
+        xmin, xmax = ax.get_xlim()
+        if start:
+            xmin = sc.day(start, start_day=start_day)
+        if end:
+            xmax = sc.day(end, start_day=start_day)
+        ax.set_xlim((xmin, xmax))
+
+        # Set the x-axis intervals
+        if interval:
+            ax.set_xticks(np.arange(xmin, xmax+1, interval))
+
+        # Set the formatter
         ax.xaxis.set_major_formatter(mpl_formatter)
 
     return mpl_formatter
@@ -290,7 +311,7 @@ def reset_ticks(ax, sim=None, date_args=None, start_day=None):
 
     # Set the x-axis intervals
     if date_args.interval:
-        ax.set_xticks(pl.arange(xmin, xmax+1, date_args.interval))
+        ax.set_xticks(np.arange(xmin, xmax+1, date_args.interval))
 
     # Set xticks as dates
     if date_args.as_dates:
