@@ -25,7 +25,7 @@ class Sim(cvb.BaseSim):
     The Sim class handles the running of the simulation: the creation of the
     population and the dynamics of the epidemic. This class handles the mechanics
     of the actual simulation, while BaseSim takes care of housekeeping (saving,
-    loading, exporting, etc.).
+    loading, exporting, etc.). Please see the BaseSim class for additional methods.
 
     Args:
         pars     (dict):   parameters to modify from their default values
@@ -116,7 +116,7 @@ class Sim(cvb.BaseSim):
         self.initialized   = True
         self.complete      = False
         self.results_ready = False
-        return
+        return self
 
 
     def layer_keys(self):
@@ -426,6 +426,10 @@ class Sim(cvb.BaseSim):
 
         return
 
+    def finalize_interventions(self):
+        for intervention in self['interventions']:
+            if isinstance(intervention, cvi.Intervention):
+                intervention.finalize(self)
 
     def init_analyzers(self):
         ''' Initialize the analyzers '''
@@ -437,6 +441,10 @@ class Sim(cvb.BaseSim):
                 analyzer.initialize(self)
         return
 
+    def finalize_analyzers(self):
+        for analyzer in self['analyzers']:
+            if isinstance(analyzer, cva.Analyzer):
+                analyzer.finalize(self)
 
     def rescale(self):
         ''' Dynamically rescale the population -- used during step() '''
@@ -655,6 +663,10 @@ class Sim(cvb.BaseSim):
             self.results[f'cum_{key}'][:] = np.cumsum(self.results[f'new_{key}'][:])
         self.results['cum_infections'].values += self['pop_infected']*self.rescale_vec[0] # Include initially infected people
 
+        # Finalize interventions and analyzers
+        self.finalize_interventions()
+        self.finalize_analyzers()
+
         # Final settings
         self.results_ready = True # Set this first so self.summary() knows to print the results
         self.t -= 1 # During the run, this keeps track of the next step; restore this be the final day of the sim
