@@ -89,15 +89,24 @@ def compute_trans_sus(rel_trans,  rel_sus,    inf,       sus,       beta_layer,
 
 @nb.njit(             (nbfloat,  nbint[:], nbint[:],  nbfloat[:],  nbfloat[:], nbfloat[:]), cache=cache, parallel=rand_parallel)
 def compute_infections(beta,     sources,  targets,   layer_betas, rel_trans,  rel_sus): # pragma: no cover
-    ''' The heaviest step of the model -- figure out who gets infected on this timestep. Cannot be parallelized since random numbers are used '''
-    betas           = beta * layer_betas  * rel_trans[sources] * rel_sus[targets] # Calculate the raw transmission probabilities
-    nonzero_inds    = betas.nonzero()[0] # Find nonzero entries
-    nonzero_betas   = betas[nonzero_inds] # Remove zero entries from beta
-    nonzero_sources = sources[nonzero_inds] # Remove zero entries from the sources
-    nonzero_targets = targets[nonzero_inds] # Remove zero entries from the targets
-    transmissions   = (np.random.random(len(nonzero_betas)) < nonzero_betas).nonzero()[0] # Compute the actual infections!
-    source_inds     = nonzero_sources[transmissions]
-    target_inds     = nonzero_targets[transmissions] # Filter the targets on the actual infections
+    '''
+    Compute who infects whom
+
+    The heaviest step of the model, taking about 50% of the total time -- figure
+    out who gets infected on this timestep. Cannot be easily parallelized since
+    random numbers are used.
+    '''
+    source_trans     = rel_trans[sources] # Pull out the transmissibility of the sources (0 for non-infectious people)
+    inf_inds         = source_trans.nonzero()[0] # Infectious indices -- remove noninfectious people
+    betas            = beta * layer_betas[inf_inds] * source_trans[inf_inds] * rel_sus[targets[inf_inds]] # Calculate the raw transmission probabilities
+    nonzero_inds     = betas.nonzero()[0] # Find nonzero entries
+    nonzero_inf_inds = inf_inds[nonzero_inds] # Map onto original indices
+    nonzero_betas    = betas[nonzero_inds] # Remove zero entries from beta
+    nonzero_sources  = sources[nonzero_inf_inds] # Remove zero entries from the sources
+    nonzero_targets  = targets[nonzero_inf_inds] # Remove zero entries from the targets
+    transmissions    = (np.random.random(len(nonzero_betas)) < nonzero_betas).nonzero()[0] # Compute the actual infections!
+    source_inds      = nonzero_sources[transmissions]
+    target_inds      = nonzero_targets[transmissions] # Filter the targets on the actual infections
     return source_inds, target_inds
 
 
@@ -168,33 +177,38 @@ def sample(dist=None, par1=None, par2=None, size=None, **kwargs):
         the mean.
     '''
 
+    # Some of these have aliases, but these are the "official" names
     choices = [
         'uniform',
         'normal',
-        'lognormal',
         'normal_pos',
         'normal_int',
+        'lognormal',
         'lognormal_int',
         'poisson',
         'neg_binomial',
-        ]
+    ]
+
+    # Ensure it's an integer
+    if size is not None:
+        size = int(size)
 
     # Compute distribution parameters and draw samples
     # NB, if adding a new distribution, also add to choices above
-    if   dist == 'uniform':       samples = np.random.uniform(low=par1, high=par2, size=size, **kwargs)
-    elif dist == 'normal':        samples = np.random.normal(loc=par1, scale=par2, size=size, **kwargs)
-    elif dist == 'normal_pos':    samples = np.abs(np.random.normal(loc=par1, scale=par2, size=size, **kwargs))
-    elif dist == 'normal_int':    samples = np.round(np.abs(np.random.normal(loc=par1, scale=par2, size=size, **kwargs)))
-    elif dist == 'poisson':       samples = n_poisson(rate=par1, n=size, **kwargs) # Use Numba version below for speed
-    elif dist == 'neg_binomial':  samples = n_neg_binomial(rate=par1, dispersion=par2, n=size, **kwargs) # Use custom version below
-    elif dist in ['lognormal', 'lognormal_int']:
+    if   dist in ['unif', 'uniform']: samples = np.random.uniform(low=par1, high=par2, size=size, **kwargs)
+    elif dist in ['norm', 'normal']:  samples = np.random.normal(loc=par1, scale=par2, size=size, **kwargs)
+    elif dist == 'normal_pos':        samples = np.abs(np.random.normal(loc=par1, scale=par2, size=size, **kwargs))
+    elif dist == 'normal_int':        samples = np.round(np.abs(np.random.normal(loc=par1, scale=par2, size=size, **kwargs)))
+    elif dist == 'poisson':           samples = n_poisson(rate=par1, n=size, **kwargs) # Use Numba version below for speed
+    elif dist == 'neg_binomial':      samples = n_neg_binomial(rate=par1, dispersion=par2, n=size, **kwargs) # Use custom version below
+    elif dist in ['lognorm', 'lognormal', 'lognorm_int', 'lognormal_int']:
         if par1>0:
             mean  = np.log(par1**2 / np.sqrt(par2**2 + par1**2)) # Computes the mean of the underlying normal distribution
             sigma = np.sqrt(np.log(par2**2/par1**2 + 1)) # Computes sigma for the underlying normal distribution
             samples = np.random.lognormal(mean=mean, sigma=sigma, size=size, **kwargs)
         else:
             samples = np.zeros(size)
-        if dist == 'lognormal_int':
+        if '_int' in dist:
             samples = np.round(samples)
     else:
         choicestr = '\n'.join(choices)
