@@ -71,11 +71,11 @@ def test_poisson():
     return s3
 
 
-def test_samples(do_plot=False):
+def test_samples(do_plot=False, verbose=True):
     sc.heading('Samples distribution')
 
-    n = 10000
-    nbins = 40
+    n = 200_000
+    nbins = 100
 
     # Warning, must match utils.py!
     choices = [
@@ -85,6 +85,7 @@ def test_samples(do_plot=False):
         'normal_pos',
         'normal_int',
         'lognormal_int',
+        'poisson',
         'neg_binomial'
         ]
 
@@ -93,28 +94,75 @@ def test_samples(do_plot=False):
 
     # Run the samples
     nchoices = len(choices)
-    nsqr = np.ceil(np.sqrt(nchoices))
-    results = {}
+    nsqr, _ = sc.get_rows_cols(nchoices)
+    results = sc.objdict()
+    mean = 11
+    std = 7
+    low = 3
+    high = 9
+    normal_dists = ['normal', 'normal_pos', 'normal_int', 'lognormal', 'lognormal_int']
     for c,choice in enumerate(choices):
-        if choice == 'neg_binomial':
-            par1 = 10
-            par2 = 0.5
-        elif choice in ['lognormal', 'lognormal_int']:
-            par1 = 1
-            par2 = 0.5
+        kw = {}
+        if choice in normal_dists:
+            par1 = mean
+            par2 = std
+        elif choice == 'neg_binomial':
+            par1 = mean
+            par2 = 1.2
+            kw['step'] = 0.1
+        elif choice == 'poisson':
+            par1 = mean
+            par2 = 0
+        elif choice == 'uniform':
+            par1 = low
+            par2 = high
         else:
-            par1 = 0
-            par2 = 5
-        results[choice] = cv.sample(dist=choice, par1=par1, par2=par2, size=n)
+            errormsg = f'Choice "{choice}" not implemented'
+            raise NotImplementedError(errormsg)
 
+        # Compute
+        results[choice] = cv.sample(dist=choice, par1=par1, par2=par2, size=n, **kw)
+
+        # Optionally plot
         if do_plot:
             pl.subplot(nsqr, nsqr, c+1)
-            pl.hist(x=results[choice], bins=nbins)
+            plotbins = np.unique(results[choice]) if (choice=='poisson' or '_int' in choice) else nbins
+            pl.hist(x=results[choice], bins=plotbins, width=0.8)
             pl.title(f'dist={choice}, par1={par1}, par2={par2}')
 
     with pytest.raises(NotImplementedError):
         cv.sample(dist='not_found')
 
+    # Do statistical tests
+    tol = 1/np.sqrt(n/50/len(choices)) # Define acceptable tolerance -- broad to avoid false positives
+
+    def isclose(choice, tol=tol, **kwargs):
+        key = list(kwargs.keys())[0]
+        ref = list(kwargs.values())[0]
+        npfunc = getattr(np, key)
+        value = npfunc(results[choice])
+        msg = f'Test for {choice:14s}: expecting {key:4s} = {ref:8.4f} ± {tol*ref:8.4f} and got {value:8.4f}'
+        if verbose:
+            print(msg)
+        assert np.isclose(value, ref, rtol=tol), msg
+        return True
+
+    # Normal
+    for choice in normal_dists:
+        isclose(choice, mean=mean)
+        if all([k not in choice for k in ['_pos', '_int']]): # These change the variance
+            isclose(choice, std=std)
+
+    # Negative binomial
+    isclose('neg_binomial', mean=mean)
+
+    # Poisson
+    isclose('poisson', mean=mean)
+    isclose('poisson', var=mean)
+
+    # Uniform
+    isclose('uniform', mean=(low+high)/2)
+
     return results
 
 
